# Python Slack Terminal #
[![Build Status](https://travis-ci.com/chestm007/py_slack_terminal.svg?branch=master)](https://travis-ci.com/chestm007/py_slack_terminal) 

## install ##
```
$ pip install py_slack_terminal
```

## running ##

```
$ slack-term
```

## authentication ##

on first launch, you'll be prompted to enter your slack token, this wil then be saved in `~/.config/_py_slack_term/config.yml`

 -- alternatively

set your token in `~/.config/py_slack_term/config.yml`

```
slacktoken: <token here>
```


